@@ -9,10 +9,6 @@ use utf8;
 
 WWW::Suffit::Client - The Suffit API client library
 
-=head1 VERSION
-
-Version 1.01
-
 =head1 SYNOPSIS
 
     use WWW::Suffit::Client;
@@ -38,6 +34,17 @@ Version 1.01
 
 This library provides methods for access to Suffit API servers
 
+=head1 METHODS
+
+List of extended API methods
+
+=head2 apierr
+
+    die $client->apierr;
+
+This method returns the value of the "/message" API parameter or a client error if no message found.
+Otherwise, this method returns a string containing an HTTP error message
+
 =head1 API METHODS
 
 List of predefined the Suffit API methods
@@ -101,7 +108,7 @@ See C<LICENSE> file and L<https://dev.perl.org/licenses/>
 
 =cut
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use parent qw/ WWW::Suffit::UserAgent /;
 
@@ -109,6 +116,11 @@ use WWW::Suffit::Const qw/ :MIME /;
 
 ## SUFFIT API COMMON METHODS
 
+sub apierr {
+    my $self = shift;
+    return $self->res->json("/message") || $self->error || $self->res->message
+};
+
 sub api_check {
     my $self = shift;
     my $url = shift || 'check'; # URL or String (e.g.: api/check)
